/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.person.entity;

import com.baomidou.mybatisplus.annotation.TableName;
import com.baomidou.mybatisplus.annotation.Version;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.models.auth.In;
import lombok.Data;
import lombok.EqualsAndHashCode;
import org.springblade.core.mp.base.BaseEntity;

/**
 * 实体类
 * 小区
 * @author zyh
 */
@Data
@TableName("t_person_community")
@EqualsAndHashCode(callSuper = true)
public class Community extends BaseEntity {

	/**
	 * 小区名称
	 */
	@ApiModelProperty(value = "小区名称")
	private String tcName;

	/**
	 * 区域
	 */
	@ApiModelProperty(value = "区域")
	private String tcArea;

	/**
	 * 区域编码
	 */
	@ApiModelProperty(value = "区域编码")
	private String tcCode;

	/**
	 * 小区地址
	 */
	@ApiModelProperty(value = "小区地址")
	private String tcAddress;

	/**
	 * 小区类型 1:开放式 2:混合式 3:封闭式
	 */
	@ApiModelProperty(value = "小区类型 1:开放式 2:混合式 3:封闭式 ")
	private Integer tcType;

	/**
	 * 小区坐标(经度)
	 */
	@ApiModelProperty(value = "小区坐标(经度)")
	private String tcLongitude;

	/**
	 * 小区坐标(纬度)
	 */
	@ApiModelProperty(value = "小区坐标(纬度)")
	private String tcLatitude;

	/**
	 * 社区id
	 */
	@ApiModelProperty(value = "社区id")
	private Long saId;

	/**
	 * 小区编号
	 */
	@ApiModelProperty(value = "小区编号")
	private String tcNumber;

	/**
	 * 小区授权码
	 */
	@ApiModelProperty(value = "小区授权码")
	private String tcAuthorizationCode;

	/**
	 * app服务器配置
	 */
	@ApiModelProperty(value = "app服务器配置")
	private String tcIpConfig;

	/**
	 * 是否同步（1.否、2.是）
	 */
	@ApiModelProperty(value = "是否同步（1.否、2.是）")
	private Integer tcIsSyn;

	/**
	 * 告警天数
	 */
	@ApiModelProperty(value = "告警天数")
	private Integer alarmTime;

	/**
	 * 算法服务器ip
	 */
	@ApiModelProperty(value = "算法服务器ip")
	private String algorithmIp;

	/**
	 * 算法服务器端口
	 */
	@ApiModelProperty(value = "算法服务器端口")
	private String algorithmPort;

	/**
	 * 是否启用摄像头人脸识别开门 0不开启 1开启
	 */
	@ApiModelProperty(value = "是否启用摄像头人脸识别开门 0不开启 1开启")
	private Integer cameraOpenDoor;

	/**
	 * 小区照片
	 */
	@ApiModelProperty(value = "小区照片")
	private String tcPhoto;

	/**
	 * 公安采集平台账号
	 */
	@ApiModelProperty(value = "公安采集平台账号")
	private String username;

	/**
	 * 公安采集平台密码
	 */
	@ApiModelProperty(value = "公安采集平台密码")
	private String password;

	/**
	 * 客户端ID
	 */
	@ApiModelProperty(value = "客户端ID")
	private String clientId;

	/**
	 * 客户端secret
	 */
	@ApiModelProperty(value = "客户端secret")
	private String clientSecret;

	/**
	 * 公安平台小区ID
	 */
	@ApiModelProperty(value = "公安平台小区ID")
	private String clientCommunityId;

	/**
	 * 公安平台点位
	 */
	@ApiModelProperty(value = "公安平台点位")
	private String policePointId;

	/**
	 * 乐观锁版本号
	 */
	@Version
	private Integer version;
}
